@@ -202,7 +202,7 @@ class AEADImpl(aead_aes_hmac.AEAD):
         new_auth = (await CryptoProviderImpl.hmac_calculate(
             authentication_key,
             hash_function,
-            associated_data + ciphertext
+            associated_data + omemo_authenticated_message.message
         ))[:AEADImpl.AUTHENTICATION_TAG_TRUNCATED_LENGTH]
 
         if new_auth != omemo_authenticated_message.mac:
@@ -1504,9 +1504,10 @@ class Oldmemo(Backend):
         new_signed_pre_key_ids: Dict[bytes, int] = {}
 
         # Assign the next highest id to the signed pre key, if there is no id assigned to it yet.
+        signed_pre_key_id_counter += 1
         new_signed_pre_key_ids[signed_pre_key] = signed_pre_key_ids.get(
             signed_pre_key,
-            signed_pre_key_id_counter := signed_pre_key_id_counter + 1
+            signed_pre_key_id_counter
         )
 
         # Assign the next highest id to the old signed pre key, if there is no id assigned to it yet. This
@@ -1514,9 +1515,10 @@ class Oldmemo(Backend):
         # (non-old) signed pre key, however there might be edge cases of the signed pre key rotating twice
         # before the assigned ids are updated.
         if old_signed_pre_key is not None:
+            signed_pre_key_id_counter += 1
             new_signed_pre_key_ids[old_signed_pre_key] = signed_pre_key_ids.get(
                 old_signed_pre_key,
-                signed_pre_key_id_counter := signed_pre_key_id_counter + 1
+                signed_pre_key_id_counter
             )
 
         # If the ids have changed, store them
@@ -1560,7 +1562,8 @@ class Oldmemo(Backend):
 
         # Assign the next highest id to each pre key if there is no existing id assigned to it
         for pre_key in pre_keys:
-            new_pre_key_ids[pre_key] = pre_key_ids.get(pre_key, pre_key_id_counter := pre_key_id_counter + 1)
+            pre_key_id_counter += 1
+            new_pre_key_ids[pre_key] = pre_key_ids.get(pre_key, pre_key_id_counter)
 
         # If the ids have changed, store them
         if new_pre_key_ids != pre_key_ids:
